@@ -3,13 +3,14 @@
 
 #include <err.h>
 #include <errno.h>
-#include <inttypes.h>
 #include <libgen.h>
 #include <limits.h>
 #include <locale.h>
+#include <stdint.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <time.h>
 #include <unistd.h>
 #include <wchar.h>
 
@@ -779,11 +780,11 @@ printcommitatom(FILE *fp, struct commitinfo *ci)
 		xmlencode(fp, ci->summary, strlen(ci->summary));
 		fputs("</title>\n", fp);
 	}
-	fprintf(fp, "<link rel=\"alternate\" type=\"text/html\" href=\"commit/%s.gph\" />",
+	fprintf(fp, "<link rel=\"alternate\" type=\"text/html\" href=\"commit/%s.gph\" />\n",
 	        ci->oid);
 
 	if (ci->author) {
-		fputs("<author><name>", fp);
+		fputs("<author>\n<name>", fp);
 		xmlencode(fp, ci->author->name, strlen(ci->author->name));
 		fputs("</name>\n<email>", fp);
 		xmlencode(fp, ci->author->email, strlen(ci->author->email));
@@ -1177,6 +1178,13 @@ main(int argc, char *argv[])
 	git_libgit2_init();
 
 #ifdef __OpenBSD__
+	if (unveil(repodir, "r") == -1)
+		err(1, "unveil: %s", repodir);
+	if (unveil(".", "rwc") == -1)
+		err(1, "unveil: .");
+	if (cachefile && unveil(cachefile, "rwc") == -1)
+		err(1, "unveil: %s", cachefile);
+
 	if (cachefile) {
 		if (pledge("stdio rpath wpath cpath fattr", NULL) == -1)
 			err(1, "pledge");
